import { ManagedInstanceRole } from '@renovosolutions/cdk-library-managed-instance-role';
import { aws_ec2 as ec2, aws_iam as iam, aws_route53 as route53 } from 'aws-cdk-lib';
import { Construct } from 'constructs';
export interface InstanceServiceProps {
    /**
     * The type of instance to launch.
     */
    readonly instanceType: ec2.InstanceType;
    /**
     * AMI to launch
     */
    readonly machineImage: ec2.IMachineImage;
    /**
     * The name of the service the instance is for.
     */
    readonly name: string;
    /**
     * The VPC to launch the instance in.
     */
    readonly vpc: ec2.IVpc;
    /**
     * Whether the instance could initiate connections to anywhere by default.
     */
    readonly allowAllOutbound?: boolean;
    /**
     * Specifies how block devices are exposed to the instance. You can specify virtual devices and EBS volumes
     */
    readonly blockDevices?: ec2.BlockDevice[];
    /**
     * Name of the SSH keypair to grant access to the instance.
     */
    readonly keyName?: string;
    /**
     * Defines a private IP address to associate with the instance.
     */
    readonly privateIpAddress?: string;
    /**
     * The subnet type to launch this service in
     *
     *
     * @default ec2.SubnetType.PRIVATE_WITH_NAT
     */
    readonly subnetType?: ec2.SubnetType;
    /**
     * Select subnets only in the given AZs
     */
    readonly availabilityZones?: string[];
    /**
     * Whether or not to enable logging to Cloudwatch Logs
     *
     *
     * @default true
     */
    readonly enableCloudwatchLogs?: boolean;
    /**
     * Whether to disable inline ingress and egress rule optimization for the instances security group.
     *
     * If this is set to true, ingress and egress rules will not be declared under the SecurityGroup in cloudformation, but will be separate elements.
     *
     * Inlining rules is an optimization for producing smaller stack templates.
     * Sometimes this is not desirable, for example when security group access is managed via tags.
     *
     * The default value can be overriden globally by setting the context variable '@aws-cdk/aws-ec2.securityGroupDisableInlineRules'.
     * @default false
     */
    readonly disableInlineRules?: boolean;
    /**
     * Whether or not to prevent security group from containing rules that allow access to remote management ports:
     * SSH, RDP, WinRM, WinRM over HTTPs
     *
     * If these ports are opened when this is enabled an error will be added to CDK metadata and deployment and synth will fail.
     *
     *
     * @default true
     */
    readonly enableNoRemoteManagementPortsAspect?: boolean;
    /**
     * Whether or not to prevent security group from containing rules that allow access to relational DB ports:
     * MySQL, PostgreSQL, MariaDB, Oracle, SQL Server
     *
     * If these ports are opened when this is enabled an error will be added to CDK metadata and deployment and synth will fail.
     *
     *
     * @default true
     */
    readonly enableNoDBPortsAspect?: boolean;
    /**
     * Whether or not to prevent security group from containing rules that allow access from the public internet:
     * Any rule with a source from 0.0.0.0/0 or ::/0
     *
     * If these sources are used when this is enabled and error will be added to CDK metadata and deployment and synth will fail.
     */
    readonly enabledNoPublicIngressAspect?: boolean;
    /**
     * The parent domain of the service.
     */
    readonly parentDomain?: string;
    /**
     * The user data to apply to the instance.
     */
    readonly userData?: ec2.UserData;
    /**
     * The role to use for this instance
     *
     * @default - A new ManagedInstanceRole will be created for this instance
     */
    readonly instanceRole?: ManagedInstanceRole;
    /**
     * The security group to use for this instance
     *
     * @default - A new SecurityGroup will be created for this instance
     */
    readonly securityGroup?: ec2.SecurityGroup;
    /**
     * Whether IMDSv2 should be required on this instance.
     *
     * @default true
     */
    readonly requireImdsv2?: boolean;
    /**
     * Whether to use th IMDSv2 custom aspect provided by this library or the default one provided by AWS.
     *
     * Turned on by default otherwise we need to apply a feature flag to every project using an instance or
     * apply a breaking change to instance construct ids.
     *
     * @see https://github.com/jericht/aws-cdk/blob/56c01aedc4f745eec79409c99b749f516ffc39e1/packages/%40aws-cdk/aws-ec2/lib/aspects/require-imdsv2-aspect.ts#L95
     *
     * @default true
     */
    readonly useImdsv2CustomAspect?: boolean;
}
export interface ManagedLoggingPolicyProps {
    /**
     * The OS of the instance this policy is for.
     */
    readonly os: string;
}
export interface AmiLookup {
    /**
     * The name string to use for AMI lookup
     */
    readonly name: string;
    /**
     * The owners to use for AMI lookup
     */
    readonly owners?: string[];
    /**
     * Is this AMI expected to be windows?
     */
    readonly windows?: boolean;
}
export declare function ec2ImageToOsString(stack: Construct, image: ec2.IMachineImage): string;
export declare class ManagedLoggingPolicy extends Construct {
    readonly policy: iam.ManagedPolicy;
    constructor(scope: Construct, id: string, props: ManagedLoggingPolicyProps);
}
export declare class InstanceService extends Construct {
    /**
     * The instance profile associated with this instance.
     */
    readonly instanceProfile: iam.CfnInstanceProfile;
    /**
     * The instance role associated with this instance.
     */
    readonly instanceRole: ManagedInstanceRole;
    /**
     * The security group associated with this instance.
     */
    readonly securityGroup: ec2.SecurityGroup;
    /**
     * The underlying instance resource
     */
    readonly instance: ec2.Instance;
    /**
     * The underlying CfnInstance resource
     */
    readonly instanceCfn: ec2.CfnInstance;
    /**
     * The availability zone of the instance
     */
    readonly instanceAvailabilityZone: string;
    /**
     * The instance's ID
     */
    readonly instanceId: string;
    /**
     * Private DNS name for this instance assigned by EC2
     */
    readonly instanceEc2PrivateDnsName: string;
    /**
     * Private IP for this instance
     */
    readonly instancePrivateIp: string;
    /**
     * Public DNS name for this instance assigned by EC2
     */
    readonly instanceEc2PublicDnsName: string;
    /**
     * DNS record for this instance created in Route53
     */
    readonly instanceDnsName?: route53.ARecord;
    /**
     * The type of OS the instance is running
     */
    readonly osType: ec2.OperatingSystemType;
    constructor(scope: Construct, id: string, props: InstanceServiceProps);
}
